# Frequenz Microgrid API Python Bindings

[![Build Status](https://github.com/frequenz-floss/frequenz-microgrid-betterproto-python/actions/workflows/ci.yaml/badge.svg)](https://github.com/frequenz-floss/frequenz-microgrid-betterproto-python/actions/workflows/ci.yaml)
[![PyPI Package](https://img.shields.io/pypi/v/frequenz-microgrid-betterproto)](https://pypi.org/project/frequenz-microgrid-betterproto/)
[![Docs](https://img.shields.io/badge/docs-latest-informational)](https://frequenz-floss.github.io/frequenz-microgrid-betterproto-python/)

## Introduction

Bindings to the [microgrid API] generated using [betterproto].

Versions of this package matches the version of the API it is generated from.

## Supported Platforms

The following platforms are officially supported (tested):

- **Python:** 3.11
- **Operating System:** Ubuntu Linux 20.04
- **Architectures:** amd64, arm64

## Contributing

If you want to know how to build this project and contribute to it, please
check out the [Contributing Guide](CONTRIBUTING.md).

[betterproto]: https://test-betterproto.readthedocs.io/en/docs/index.html
[microgrid API]: https://frequenz-floss.github.io/frequenz-api-microgrid/
